@@ -2,18 +2,25 @@
 Contains CUDA API functions
 '''
 
+# Imports here bring together parts of the API from other modules, so some of
+# them appear unused.
 from contextlib import contextmanager
-from .cudadrv.devices import require_context, reset, gpus
+
+from .cudadrv.devices import require_context, reset, gpus  # noqa: F401
 from .kernel import FakeCUDAKernel
-from numba.core.typing import Signature
+from numba.core.sigutils import is_signature
 from warnings import warn
-from ..args import In, Out, InOut
+from ..args import In, Out, InOut  # noqa: F401
 
 
 def select_device(dev=0):
     assert dev == 0, 'Only a single device supported by the simulator'
 
 
+def is_float16_supported():
+    return True
+
+
 class stream(object):
     '''
     The stream API is supported in the simulator - however, all execution
@@ -30,6 +37,7 @@ class stream(object):
 def synchronize():
     pass
 
+
 def close():
     gpus.closed = True
 
@@ -41,7 +49,7 @@ def declare_device(*args, **kwargs):
 def detect():
     print('Found 1 CUDA devices')
     print('id %d    %20s %40s' % (0, 'SIMULATOR', '[SUPPORTED]'))
-    print('%40s: 5.2' % 'compute capability')
+    print('%40s: 5.0' % 'compute capability')
 
 
 def list_devices():
@@ -68,28 +76,32 @@ class Event(object):
         warn('Simulator timings are bogus')
         return 0.0
 
+
 event = Event
 
 
 def jit(func_or_sig=None, device=False, debug=False, argtypes=None,
         inline=False, restype=None, fastmath=False, link=None,
-        boundscheck=None,
+        boundscheck=None, opt=True, cache=None
         ):
     # Here for API compatibility
-    if boundscheck == True:
+    if boundscheck:
         raise NotImplementedError("bounds checking is not supported for CUDA")
 
     if link is not None:
         raise NotImplementedError('Cannot link PTX in the simulator')
+
     # Check for first argument specifying types - in that case the
     # decorator is not being passed a function
-    if func_or_sig is None or isinstance(func_or_sig, (str, tuple, Signature)):
+    if (func_or_sig is None or is_signature(func_or_sig)
+            or isinstance(func_or_sig, list)):
         def jitwrapper(fn):
             return FakeCUDAKernel(fn,
                                   device=device,
-                                  fastmath=fastmath)
+                                  fastmath=fastmath,
+                                  debug=debug)
         return jitwrapper
-    return FakeCUDAKernel(func_or_sig, device=device)
+    return FakeCUDAKernel(func_or_sig, device=device, debug=debug)
 
 
 @contextmanager
